% computes the steady state of fs2000 analyticaly
% largely inspired by the program of F. Schorfheide
function [ys,check] = nontraded_steadystate(ys)
  % Inputs:
  %   ys: initial values declared in INITVAL in alphabetical order of the
  %       variables
  % Ouputs:
  %   ys: computed steady state values in alphabetical order of the
  %       variables
  %   check: steady state OK=0; problem in computing steady state = 1 
  % Structural parameters of the model are declared as global  
global beta_p chi_p le_p delta_p alphan_p alphat_p ...
           chi0_p rhonn_p rhont_p omegacn_p omegact_p ...
           omegain_p omegait_p rhon_p rhot_p nfa_p;
  
  check = 0;
  
% Rental rate for capital in both sectors
r_p = (delta_p - 1 + 1/beta_p);

% sectoral saving rate
sn_p = alphan_p * delta_p/r_p;
st_p = alphat_p * delta_p/r_p;

% relative size of sectors
yn2y_p = (omegacn_p*(1-st_p) + omegain_p*st_p) /(1-omegacn_p*(st_p - sn_p)-omegain_p*(sn_p-st_p));
yt2y_p = 1-yn2y_p;

% aggregate saving rate
s_p = yn2y_p*sn_p + yt2y_p*st_p;

% output
y_p = le_p/( yt2y_p * (delta_p/st_p)^(alphat_p/(1-alphat_p)) + yn2y_p * (delta_p/sn_p)^(alphan_p/(1-alphan_p)) );
yt_p = yt2y_p * y_p;
yn_p = yn2y_p * y_p;

% sectoral labor
let_p = yt2y_p*(delta_p/st_p)^(alphat_p/(1-alphat_p))*y_p;
len_p = yn2y_p*(delta_p/sn_p)^(alphan_p/(1-alphan_p))*y_p;

% net foreign assets
nfa =0;

% net foreign assets to gdp
nfay = 0;

% consumption based-real exchange rate
q = 1;

tby = 0;

% Rental rate for capital
rn = r_p;
rt = r_p;

% investment rate
jy = s_p;
sy = s_p;
j = s_p * y_p;
jn = sn_p * yn_p;
jt = st_p * yt_p;

in = omegain_p *j;
it = (1-omegain_p) *j;
ih = omegait_p * it;
im = (1-omegait_p) * it;

% short term real rate
rs = 1/beta_p -1;

% Labor
le = le_p;
let = let_p;
len = len_p;

% Output
gdp = y_p;
yn = yn_p;
yt = yt_p;

% Consumption
cc = gdp - j;
ccn = omegacn_p * cc;
cct = (1-omegacn_p) * cc;
cch = omegact_p * cct;
ccm = (1-omegact_p) * cct;

% relative prices
pf = 1;
pn = 1;
pc = 1;
pct = 1;
pj = 1;
pit = 1;

% Capital 
kpt = jt/delta_p;
kpn = jn/delta_p;

% Rental rate for labor
wn = (1-alphan_p)*yn_p/len_p;
wt = (1-alphat_p)*yt_p/let_p;

% Multipliers
lambda = 1/cc;

gamman = lambda;
gammat = lambda;

eta = chi0_p*(1-le_p)^(-chi_p)

% Labor-augmenting technology
nn=0;
nt=0;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%/
% Steady state for country 2
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%/

% consumption based-real exchange rate
q2 = 1;
tby2 = 0;


% Rental rate for capital
rn2 = r_p;
rt2 = r_p;

% investment rate
jy2 = s_p;
sy2 = s_p;
j2 = s_p * y_p;
jn2 = sn_p * yn_p;
jt2 = st_p * yt_p;

in2 = omegain_p *j2;
it2 = (1-omegain_p) *j2;
ih2 = omegait_p * it2;
im2 = (1-omegait_p) * it2;

% short term real rate
rs2 = 1/beta_p -1;

% Labor
le2 = le_p;
let2 = let_p;
len2 = len_p;

% Output
gdp2 = y_p;
yn2 = yn_p;
yt2 = yt_p;

% Consumption
cc2 = gdp2 - j2;
ccn2 = omegacn_p * cc2;
cct2 = (1-omegacn_p) * cc2;
cch2 = omegact_p * cct2;
ccm2 = (1-omegact_p) * cct2;

% relative prices
pf2 = 1;
pn2 = 1;
pc2 = 1;
pct2 = 1;
pj2 = 1;
pit2 = 1;

% Capital 
kpt2 = jt2/delta_p;
kpn2 = jn2/delta_p;

% Rental rate for labor
wn2 = alphan_p*yn_p/len_p;
wt2 = alphat_p*yt_p/let_p;

% Multipliers
lambda2 = 1/cc2;

gamman2 = lambda2;
gammat2 = lambda2;

eta2 = chi0_p*(1-le_p)^(-chi_p);

% Labor-augmenting technology
nn2=0;
nt2=0;
  



  ys =[cc     
cc2    
cch    
cch2   
ccm    
ccm2   
ccn    
ccn2   
cct    
cct2   
eta    
eta2   
gamman 
gamman2
gammat 
gammat2
gdp    
gdp2   
ih     
ih2    
im     
im2    
in     
in2    
it     
it2    
j      
j2     
jn     
jn2    
jt     
jt2    
jy     
jy2    
kpn    
kpn2   
kpt    
kpt2   
lambda 
lambda2
le     
le2    
len    
len2   
let    
let2   
nfa    
nfay   
nn     
nn2    
nt     
nt2    
pc     
pc2    
pct    
pct2   
pf     
pf2    
pit    
pit2   
pj     
pj2    
pn     
pn2    
q      
q2     
rn     
rn2    
rs     
rs2    
rt     
rt2    
sy     
sy2    
tby    
tby2   
wn     
wn2    
wt     
wt2    
yn     
yn2    
yt     
yt2];